package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseInspectRoute;
import com.aucma.dms.service.IDmsBaseInspectRouteService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 巡检线路信息Controller
 * 
 * @author Open Platform
 * @date 2024-01-16
 */
@RestController
@RequestMapping("/dms/dmsBaseInspectRoute")
public class DmsBaseInspectRouteController extends BaseController
{
    @Autowired
    private IDmsBaseInspectRouteService dmsBaseInspectRouteService;

    /**
     * 查询巡检线路信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        startPage();
        List<DmsBaseInspectRoute> list = dmsBaseInspectRouteService.selectDmsBaseInspectRouteList(dmsBaseInspectRoute);
        return getDataTable(list);
    }

    /**
     * 查询巡检线路列表
     */
    @GetMapping("/getdmsBaseInspectRouteList")
    public AjaxResult getdmsBaseInspectRouteList(DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        List<DmsBaseInspectRoute> list = dmsBaseInspectRouteService
                .selectDmsBaseInspectRouteList(dmsBaseInspectRoute);
        return success(list);
    }

    /**
     * 导出巡检线路信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:export')" )
    ////@Log(title = "巡检线路信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        List<DmsBaseInspectRoute> list = dmsBaseInspectRouteService.selectDmsBaseInspectRouteList(dmsBaseInspectRoute);
        ExcelUtil<DmsBaseInspectRoute> util = new ExcelUtil<DmsBaseInspectRoute>(DmsBaseInspectRoute.class);
        util.exportExcel(response, list, "巡检线路信息数据");
    }

    /**
     * 获取巡检线路信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:query')" )
    @GetMapping(value = "/{inspectRouteId}")
    public AjaxResult getInfo(@PathVariable("inspectRouteId") Long inspectRouteId)
    {
        return success(dmsBaseInspectRouteService.selectDmsBaseInspectRouteByInspectRouteId(inspectRouteId));
    }

    /**
     * 新增巡检线路信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:add')" )
    ////@Log(title = "巡检线路信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        return toAjax(dmsBaseInspectRouteService.insertDmsBaseInspectRoute(dmsBaseInspectRoute));
    }

    /**
     * 修改巡检线路信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:edit')" )
    ////@Log(title = "巡检线路信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseInspectRoute dmsBaseInspectRoute)
    {
        return toAjax(dmsBaseInspectRouteService.updateDmsBaseInspectRoute(dmsBaseInspectRoute));
    }

    /**
     * 删除巡检线路信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:dmsBaseInspectRoute:remove')" )
    ////@Log(title = "巡检线路信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{inspectRouteIds}")
    public AjaxResult remove(@PathVariable Long[] inspectRouteIds)
    {
        return toAjax(dmsBaseInspectRouteService.deleteDmsBaseInspectRouteByInspectRouteIds(inspectRouteIds));
    }
}
